@@ -2,10 +2,10 @@
 # function to read protein data and calculate compositional parameters
 # 20160705 jmd
 
-protcomp <- function(uniprot=NULL, ip=NULL, basis="QEC", aa_file=NULL, updates_file=NULL) {
-  if(is.null(ip)) {
+protcomp <- function(uniprot = NULL, basis = "rQEC", aa = NULL, aa_file = NULL) {
+  if(is.null(aa)) {
     # get amino acid compositions of human proteins
-    aa <- get("human_aa", canprot)
+    aa <- get("human_aa", human)
     # add amino acid compositions from external file if specified
     if(!is.null(aa_file)) {
       aa_dat <- read.csv(aa_file, as.is=TRUE)
@@ -15,24 +15,6 @@ protcomp <- function(uniprot=NULL, ip=NULL, basis="QEC", aa_file=NULL, updates_f
     if(is.null(uniprot)) {
       stop("'uniprot' is NULL")
     } else {
-      # convert old to new uniprot IDs
-      updates <- get("uniprot_updates", canprot)
-      # include updates from external file if specified
-      if(!is.null(updates_file)) {
-        updates_dat <- read.csv(updates_file, as.is=TRUE)
-        updates <- rbind(updates_dat, updates)
-      }
-      iold <- match(uniprot, updates$old)
-      if(any(!is.na(iold))) {
-        oldIDs <- updates$old[na.omit(iold)]
-        newIDs <- updates$new[na.omit(iold)]
-        print(paste("protcomp: updating", sum(!is.na(iold)), "old UniProt IDs:", paste(oldIDs, collapse=" ")))
-        # check if new IDs are duplicated
-        idup <- newIDs %in% uniprot
-        if(any(idup)) print(paste("protcomp: new IDs in updates",
-          paste(oldIDs[idup], newIDs[idup], sep="->", collapse=" "), "are duplicated in dataset"))
-        uniprot[!is.na(iold)] <- newIDs
-      }
       # find the proteins listed in 'uniprot' - first look at the ID after the | separator
       alluni <- sapply(strsplit(aa$protein, "|", fixed=TRUE), "[", 2)
       # if that is NA (i.e. no | separator is present) use the entire string
@@ -46,23 +28,22 @@ protcomp <- function(uniprot=NULL, ip=NULL, basis="QEC", aa_file=NULL, updates_f
         paste(uniprot[duplicated(iuni)], collapse=" ")), immediate.=TRUE)
       aa <- aa[iuni, ]
     }
-  } else {
-    # ip is given, for pre-loaded proteins, used by canstab()
-    aa <- ip
   }
   # protein formula, average oxidation state of carbon
   protein.formula <- CHNOSZ::protein.formula(aa)
   ZC <- CHNOSZ::ZC(protein.formula)
   # basis species for proteins, protein length, basis species in residue
-  basis(basis)
+  if(basis=="rQEC") basis("QEC") 
+  else basis(basis)
   protein.basis <- protein.basis(aa)
   protein.length <- protein.length(aa)
   residue.basis <- protein.basis / protein.length
+  # FIXME: these values really aren't "basis" values 20191205
+  if(basis == "rQEC") residue.basis[, "H2O"] <- H2OAA(aa, basis)
   # residue formula
   residue.formula <- protein.formula / protein.length
   # return data
-  out <- list(protein.formula=protein.formula, ZC=ZC, protein.basis=protein.basis,
+  out <- list(uniprot = uniprot, protein.formula=protein.formula, ZC=ZC, protein.basis=protein.basis,
     protein.length=protein.length, residue.basis=residue.basis, residue.formula=residue.formula, aa=aa)
   return(out)
 }
-
